@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: cheapskate
 version: 0.1.0.4
-id: cheapskate-0.1.0.4-99dbe614d2e414c63e0cb14960ec401b
-key: cheap_DbWTwUmY0bmHbSpxJlP7rw
+id: cheapskate-0.1.0.4-3bca36ddfca79c352f8e4daae1c4e533
+key: cheap_CVH5scrcse27LeQNUCgbqZ
 license: BSD3
 copyright: (C) 2012-2013 John MacFarlane
 maintainer: jgm@berkeley.edu
@@ -31,7 +31,7 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/cheapskate-0.1.0.4
 library-dirs: /usr/lib/ghc-7.10.3/site-local/cheapskate-0.1.0.4
 data-dir: /usr/share/arm-linux-ghc-7.10.3/cheapskate-0.1.0.4
-hs-libraries: HScheapskate-0.1.0.4-DbWTwUmY0bmHbSpxJlP7rw
+hs-libraries: HScheapskate-0.1.0.4-CVH5scrcse27LeQNUCgbqZ
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     blaze-html-0.8.1.1-1d54daeba5477a1aa0462b832a558865
